# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.1.0/).

## [Unreleased]

## [1.0.4] - 2024-09-09

### Added

- `ollama-tk` GUI script as an alias of `ollamatk`

### Changed

- README improvements:
  - Demonstration animation
    - Re-record with latest changes
    - Fix GIF not being rendered on PyPI
  - Show new PyPI installation instructions

## [1.0.3] - 2024-09-09

This is our first release to go on PyPI! 🎉

### Added

- Export all classes and functions from package
- `py.typed` package marker

## [1.0.2] - 2024-09-08

### Added

- Better error messages for unsuccessful HTTP status codes
- HTTP connection pooling for improved network efficiency
- "About" menu to view project version and summary

## [1.0.1] - 2024-09-07

### Fixed

- Fix chat being continuously forced to bottom

## [1.0.0] - 2024-09-07

This is the first release of ollama-tk! 🎉

[Unreleased]: https://github.com/thegamecracks/ollama-tk/compare/v1.0.4...main
[1.0.4]: https://github.com/thegamecracks/ollama-tk/compare/v1.0.3...v1.0.4
[1.0.3]: https://github.com/thegamecracks/ollama-tk/compare/v1.0.2...v1.0.3
[1.0.2]: https://github.com/thegamecracks/ollama-tk/compare/v1.0.1...v1.0.2
[1.0.1]: https://github.com/thegamecracks/ollama-tk/compare/v1.0.0...v1.0.1
[1.0.0]: https://github.com/thegamecracks/ollama-tk/releases/tag/v1.0.0
